dlls: Assorted spelling fixes

Frédéric Delanoy frederic.delanoy at gmail.com
Sat Jul 30 05:03:08 CDT 2011


---
 dlls/avifil32/api.c               |    4 ++--
 dlls/avifil32/getframe.c          |    2 +-
 dlls/cabinet/fdi.c                |    6 +++---
 dlls/comctl32/comboex.c           |    2 +-
 dlls/comctl32/commctrl.c          |   10 +++++-----
 dlls/comctl32/listview.c          |    8 ++++----
 dlls/comctl32/monthcal.c          |   16 ++++++++--------
 dlls/comctl32/toolbar.c           |   14 +++++++-------
 dlls/comdlg32/filedlg.c           |    2 +-
 dlls/comdlg32/filedlg31.c         |    2 +-
 dlls/comdlg32/filedlgbrowser.h    |    2 +-
 dlls/comdlg32/finddlg.c           |    2 +-
 dlls/comdlg32/printdlg.c          |    2 +-
 dlls/commdlg.dll16/filedlg.c      |    4 ++--
 dlls/commdlg.dll16/finddlg.c      |    2 +-
 dlls/credui/credui_main.c         |    2 +-
 dlls/crypt32/oid.c                |    2 +-
 dlls/crypt32/serialize.c          |    2 +-
 dlls/cryptnet/cryptnet_main.c     |    2 +-
 dlls/d3d10/effect.c               |    2 +-
 dlls/d3d8/device.c                |    2 +-
 dlls/d3d8/vertexdeclaration.c     |    2 +-
 dlls/d3dcompiler_43/asmparser.c   |    3 +--
 dlls/d3dxof/parsing.c             |    2 +-
 dlls/dbghelp/dbghelp_private.h    |    2 +-
 dlls/dbghelp/dwarf.c              |    2 +-
 dlls/dbghelp/elf_module.c         |    6 +++---
 dlls/dbghelp/msc.c                |    2 +-
 dlls/dbghelp/pe_module.c          |    2 +-
 dlls/ddeml.dll16/ddeml.c          |    2 +-
 dlls/ddraw/ddraw.c                |    4 ++--
 dlls/ddraw/vertexbuffer.c         |    2 +-
 dlls/dinput/device.c              |    2 +-
 dlls/dinput/joystick_linuxinput.c |    6 +++---
 dlls/dinput/joystick_osx.c        |    2 +-
 dlls/dinput/mouse.c               |    4 ++--
 dlls/dispex/usrmarshal.c          |    2 +-
 dlls/dmband/band.c                |   14 +++++++-------
 dlls/dmband/bandtrack.c           |   10 +++++-----
 dlls/dmband/dmutils.c             |    2 +-
 dlls/dmcompos/chordmap.c          |    8 ++++----
 dlls/dmime/audiopath.c            |    8 ++++----
 dlls/dmime/dmutils.c              |    2 +-
 dlls/dmime/graph.c                |    8 ++++----
 dlls/dmime/segment.c              |   16 ++++++++--------
 dlls/dmime/segtriggertrack.c      |    6 +++---
 46 files changed, 104 insertions(+), 105 deletions(-)

diff --git a/dlls/avifil32/api.c b/dlls/avifil32/api.c
index ea53224..c53897a 100644
--- a/dlls/avifil32/api.c
+++ b/dlls/avifil32/api.c
@@ -1024,8 +1024,8 @@ HRESULT WINAPI AVIBuildFilterW(LPWSTR szFilter, LONG cbFilter, BOOL fSaving)
 
   /*
    * 1. iterate over HKEY_CLASSES_ROOT\\AVIFile\\Extensions and collect
-   *    extensions and CLSID's
-   * 2. iterate over collected CLSID's and copy its description and its
+   *    extensions and CLSIDs
+   * 2. iterate over collected CLSIDs and copy its description and its
    *    extensions to szFilter if it fits
    *
    * First filter is named "All multimedia files" and its filter is a
diff --git a/dlls/avifil32/getframe.c b/dlls/avifil32/getframe.c
index c24009c..547f340 100644
--- a/dlls/avifil32/getframe.c
+++ b/dlls/avifil32/getframe.c
@@ -215,7 +215,7 @@ static LPVOID  WINAPI IGetFrame_fnGetFrame(IGetFrame *iface, LONG lPos)
 	if (FAILED(AVIStreamSampleSize(This->pStream, lNext, &readBytes)))
 	  return NULL; /* bad thing, but bad things will happen */
 	if (readBytes <= 0) {
-	  ERR(": IAVIStream::REad doesn't return needed bytes!\n");
+	  ERR(": IAVIStream::Read doesn't return needed bytes!\n");
 	  return NULL;
 	}
 
diff --git a/dlls/cabinet/fdi.c b/dlls/cabinet/fdi.c
index a004c1d..04a6295 100644
--- a/dlls/cabinet/fdi.c
+++ b/dlls/cabinet/fdi.c
@@ -48,7 +48,7 @@
  * Test unit(s).
  *
  * The fdintNEXT_CABINET callbacks are probably not working quite as they should.
- * There are several FIXME's in the source describing some of the deficiencies in
+ * There are several FIXMEs in the source describing some of the deficiencies in
  * some detail.  Additionally, we do not do a very good job of returning the right
  * error codes to this callback.
  *
@@ -2731,7 +2731,7 @@ BOOL __cdecl FDICopy(
 
         TRACE("Resetting folder for file %s.\n", debugstr_a(file->filename));
 
-        /* free stuff for the old decompresser */
+        /* free stuff for the old decompressor */
         switch (ct2) {
         case cffoldCOMPTYPE_LZX:
           if (LZX(window)) {
@@ -2752,7 +2752,7 @@ BOOL __cdecl FDICopy(
         CAB(offset) = 0;
         CAB(outlen) = 0;
 
-        /* initialize the new decompresser */
+        /* initialize the new decompressor */
         switch (ct1) {
         case cffoldCOMPTYPE_NONE:
           CAB(decompress) = NONEfdi_decomp;
diff --git a/dlls/comctl32/comboex.c b/dlls/comctl32/comboex.c
index d6b0d8c..b8cb359 100644
--- a/dlls/comctl32/comboex.c
+++ b/dlls/comctl32/comboex.c
@@ -97,7 +97,7 @@ typedef struct
  * Special flag set in DRAWITEMSTRUCT itemState field. It is set by
  * the ComboEx version of the Combo Window Proc so that when the
  * WM_DRAWITEM message is then passed to ComboEx, we know that this
- * particular WM_DRAWITEM message is for listbox only items. Any messasges
+ * particular WM_DRAWITEM message is for listbox only items. Any message
  * without this flag is then for the Edit control field.
  *
  * We really cannot use the ODS_COMBOBOXEDIT flag because MSDN states that
diff --git a/dlls/comctl32/commctrl.c b/dlls/comctl32/commctrl.c
index e06638c..38cadad 100644
--- a/dlls/comctl32/commctrl.c
+++ b/dlls/comctl32/commctrl.c
@@ -192,7 +192,7 @@ static BOOL create_manifest( BOOL install )
  * PARAMS
  *     hinstDLL    [I] handle to the 'dlls' instance
  *     fdwReason   [I]
- *     lpvReserved [I] reserverd, must be NULL
+ *     lpvReserved [I] reserved, must be NULL
  *
  * RETURNS
  *     Success: TRUE
@@ -701,7 +701,7 @@ CreateUpDownControl (DWORD style, INT x, INT y, INT cx, INT cy,
  *
  * NOTES
  *     This function is just a dummy - all the controls are registered at
- *     the DLL's initialization. See InitCommonContolsEx for details.
+ *     the DLL initialization time. See InitCommonContolsEx for details.
  */
 
 VOID WINAPI
@@ -1088,7 +1088,7 @@ VOID WINAPI InitMUILanguage (LANGID uiLang)
  * PARAMS
  *     hWnd [in] handle to window subclass.
  *     pfnSubclass [in] Pointer to new window procedure.
- *     uIDSubclass [in] Unique identifier of sublass together with pfnSubclass.
+ *     uIDSubclass [in] Unique identifier of subclass together with pfnSubclass.
  *     dwRef [in] Reference data to pass to window procedure.
  *
  * RETURNS
@@ -1177,7 +1177,7 @@ BOOL WINAPI SetWindowSubclass (HWND hWnd, SUBCLASSPROC pfnSubclass,
  * PARAMS
  *     hWnd [in] Handle to window which were subclassing
  *     pfnSubclass [in] Pointer to the subclass procedure
- *     uID [in] Unique indentifier of the subclassing procedure
+ *     uID [in] Unique identifier of the subclassing procedure
  *     pdwRef [out] Pointer to the reference data
  *
  * RETURNS
@@ -1320,7 +1320,7 @@ static LRESULT WINAPI COMCTL32_SubclassProc (HWND hWnd, UINT uMsg, WPARAM wParam
 /***********************************************************************
  * DefSubclassProc [COMCTL32.413]
  *
- * Calls the next window procedure (ie. the one before this subclass)
+ * Calls the next window procedure (i.e. the one before this subclass)
  *
  * PARAMS
  *     hWnd [in] The window that we're subclassing
diff --git a/dlls/comctl32/listview.c b/dlls/comctl32/listview.c
index eb94d1d..bcfd173 100644
--- a/dlls/comctl32/listview.c
+++ b/dlls/comctl32/listview.c
@@ -1296,7 +1296,7 @@ static RANGE iterator_range(const ITERATOR *i)
 }
 
 /***
- * Releases resources associated with this ierator.
+ * Releases resources associated with this iterator.
  */
 static inline void iterator_destroy(const ITERATOR *i)
 {
@@ -4938,7 +4938,7 @@ static void LISTVIEW_RefreshReportGrid(LISTVIEW_INFO *infoPtr, HDC hdc)
             LineTo (hdc, rcItem.right, infoPtr->rcList.bottom);
         }
 
-        /* draw the horizontial lines for the rows */
+        /* draw the horizontal lines for the rows */
         itemheight =  LISTVIEW_CalculateItemHeight(infoPtr);
         rcItem.left   = infoPtr->rcList.left;
         rcItem.right  = infoPtr->rcList.right;
@@ -5543,7 +5543,7 @@ static BOOL LISTVIEW_DeleteColumn(LISTVIEW_INFO *infoPtr, INT nColumn)
 		}
 	    }
 
-	    /* if we found our subitem, zapp it */	
+	    /* if we found our subitem, zap it */
 	    if (nSubItem > 0)
 	    {
 		/* free string */
@@ -8418,7 +8418,7 @@ static DWORD LISTVIEW_SetExtendedListViewStyle(LISTVIEW_INFO *infoPtr, DWORD dwM
                 ImageList_Destroy(infoPtr->himlState);
         }
         himl = LISTVIEW_SetImageList(infoPtr, LVSIL_STATE, himl);
-        /*   checkbox list replaces prevous custom list or... */
+        /*   checkbox list replaces previous custom list or... */
         if(((infoPtr->dwLvExStyle & LVS_EX_CHECKBOXES) &&
            !(infoPtr->dwStyle & LVS_SHAREIMAGELISTS)) ||
             /* ...previous was checkbox list */
diff --git a/dlls/comctl32/monthcal.c b/dlls/comctl32/monthcal.c
index ccede7f..27d2cf0 100644
--- a/dlls/comctl32/monthcal.c
+++ b/dlls/comctl32/monthcal.c
@@ -68,7 +68,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(monthcal);
 					   to the next/prev month */
 #define MC_TODAYUPDATEDELAY 120000 /* time between today check for update (2 min) */
 
-#define MC_PREVNEXTMONTHTIMER   1	/* Timer ID's */
+#define MC_PREVNEXTMONTHTIMER   1	/* Timer IDs */
 #define MC_TODAYUPDATETIMER     2
 
 #define countof(arr) (sizeof(arr)/sizeof(arr[0]))
@@ -199,7 +199,7 @@ static inline void MONTHCAL_NotifySelect(const MONTHCAL_INFO *infoPtr)
 }
 
 /* returns the number of days in any given month, checking for leap days */
-/* january is 1, december is 12 */
+/* January is 1, December is 12 */
 int MONTHCAL_MonthLength(int month, int year)
 {
   const int mdays[] = {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31};
@@ -286,7 +286,7 @@ static void MONTHCAL_CopyDate(const SYSTEMTIME *from, SYSTEMTIME *to)
  *   0 : first == second
  *   1 : first >  second
  *
- *  Note that no date validation performed, alreadt validated values expected.
+ *  Note that no date validation performed, already validated values expected.
  */
 static LONG MONTHCAL_CompareSystemTime(const SYSTEMTIME *first, const SYSTEMTIME *second)
 {
@@ -331,7 +331,7 @@ static LONG MONTHCAL_CompareDate(const SYSTEMTIME *first, const SYSTEMTIME *seco
  *
  * RETURN VALUE
  *
- *  TRUE  - date whithin largest and configured range
+ *  TRUE  - date within largest and configured range
  *  FALSE - date is outside largest or configured range
  */
 static BOOL MONTHCAL_IsDateInValidRange(const MONTHCAL_INFO *infoPtr,
@@ -532,7 +532,7 @@ static void MONTHCAL_GetMaxDate(const MONTHCAL_INFO *infoPtr, SYSTEMTIME *date)
 }
 
 /* From a given point, calculate the row (weekpos), column(daypos)
-   and day in the calendar. day== 0 mean the last day of tha last month
+   and day in the calendar. day== 0 mean the last day of the last month
 */
 static int MONTHCAL_CalcDayFromPos(const MONTHCAL_INFO *infoPtr, int x, int y,
 				   int *daypos, int *weekpos)
@@ -820,7 +820,7 @@ static void MONTHCAL_PaintWeeknumbers(const MONTHCAL_INFO *infoPtr, HDC hdc, con
      The week containing Jan 1 is the first week of year
      LOCALE_IFIRSTWEEKOFYEAR == 2 (e.g. Germany):
      First week of year must contain 4 days of the new year
-     LOCALE_IFIRSTWEEKOFYEAR == 1  (what contries?)
+     LOCALE_IFIRSTWEEKOFYEAR == 1  (what countries?)
      The first week of the year must contain only days of the new year
   */
   GetLocaleInfoW(LOCALE_USER_DEFAULT, LOCALE_IFIRSTWEEKOFYEAR, buf, countof(buf));
@@ -840,7 +840,7 @@ static void MONTHCAL_PaintWeeknumbers(const MONTHCAL_INFO *infoPtr, HDC hdc, con
 
   if (date->wMonth == 1)
   {
-    /* calculate all those exceptions for january */
+    /* calculate all those exceptions for January */
     st.wDay = st.wMonth = 1;
     weeknum1 = MONTHCAL_CalculateDayOfWeek(&st, FALSE);
     if ((infoPtr->firstDay - weeknum1) % 7 > mindays)
@@ -1228,7 +1228,7 @@ MONTHCAL_GetFirstDayOfWeek(const MONTHCAL_INFO *infoPtr)
  * RETURN VALUE:
  *  Low word contains previous first day,
  *  high word indicates was first day forced with this message before or is
- *  locale difined (TRUE - was forced, FALSE - wasn't).
+ *  locale defined (TRUE - was forced, FALSE - wasn't).
  *
  * FIXME: this needs to be implemented properly in MONTHCAL_Refresh()
  * FIXME: we need more error checking here
diff --git a/dlls/comctl32/toolbar.c b/dlls/comctl32/toolbar.c
index 46584b5..d5778e3 100644
--- a/dlls/comctl32/toolbar.c
+++ b/dlls/comctl32/toolbar.c
@@ -325,7 +325,7 @@ TOOLBAR_ButtonHasString(const TBUTTON_INFO *btnPtr)
 * 		TOOLBAR_CheckStyle
 *
 * This function validates that the styles set are implemented and
-* issues FIXME's warning of possible problems. In a perfect world this
+* issues FIXMEs warning of possible problems. In a perfect world this
 * function should be null.
 */
 static void
@@ -1467,7 +1467,7 @@ TOOLBAR_WrapToolbar(TOOLBAR_INFO *infoPtr)
 *
 * +--------------------------------------------------------+ ^
 * |                    ^                     ^             | |
-* |                    | pad.cy / 2          | centred     | |
+* |                    | pad.cy / 2          | centered    | |
 * | pad.cx/2 + cxedge +--------------+     +------------+  | | DEFPAD_CY +
 * |<----------------->| nBitmapWidth |     | Text       |  | | max(nBitmapHeight, szText.cy)
 * |                   |<------------>|     |            |  | |
@@ -1483,7 +1483,7 @@ TOOLBAR_WrapToolbar(TOOLBAR_INFO *infoPtr)
 *
 * +-----------------------------------+ ^
 * |                     ^             | |
-* |                     | centred     | | LISTPAD_CY +
+* |                     | centered    | | LISTPAD_CY +
 * |                   +------------+  | | szText.cy
 * |                   | Text       |  | |
 * |                   |            |  | |
@@ -1521,13 +1521,13 @@ TOOLBAR_WrapToolbar(TOOLBAR_INFO *infoPtr)
 * |                     | pad.cy / 2  | | nBitmapHeight +
 * |                     -             | | szText.cy +
 * |                   +------------+  | | DEFPAD_CY + 1
-* |    centred        |   Bitmap   |  | |
+* |    centered       |   Bitmap   |  | |
 * |<----------------->|            |  | |
 * |                   +------------+  | |
 * |                         ^         | |
 * |                       1 |         | |
 * |                         -         | |
-* |     centred     +---------------+ | |
+* |     centered    +---------------+ | |
 * |<--------------->|      Text     | | |
 * |                 +---------------+ | |
 * +-----------------------------------+ -
@@ -1540,7 +1540,7 @@ TOOLBAR_WrapToolbar(TOOLBAR_INFO *infoPtr)
 * |                     ^                 | |
 * |                     | 2 + pad.cy / 2  | |
 * |                     -                 | | szText.cy +
-* |    centred      +-----------------+   | | pad.cy + 2
+* |    centered     +-----------------+   | | pad.cy + 2
 * |<--------------->|   Text          |   | |
 * |                 +-----------------+   | |
 * |                                       | |
@@ -4378,7 +4378,7 @@ TOOLBAR_SetButtonSize (TOOLBAR_INFO *infoPtr, LPARAM lParam)
     /*
      * The documentation also does not mention that if 0 is supplied for
      * either size, the system changes it to the default of 24 wide and
-     * 22 high. Demonstarted in ControlSpy Toolbar. GLA 3/02
+     * 22 high. Demonstrated in ControlSpy Toolbar. GLA 3/02
      */
     if (cx == 0) cx = 24;
     if (cy == 0) cy = 22;
diff --git a/dlls/comdlg32/filedlg.c b/dlls/comdlg32/filedlg.c
index 28d7c77..1e39d19 100644
--- a/dlls/comdlg32/filedlg.c
+++ b/dlls/comdlg32/filedlg.c
@@ -1511,7 +1511,7 @@ static LRESULT FILEDLG95_InitControls(HWND hwnd)
 
   /* Initialise the file name edit control */
   handledPath = FALSE;
-  TRACE("Before manipilation, file = %s, dir = %s\n", debugstr_w(fodInfos->filename), debugstr_w(fodInfos->initdir));
+  TRACE("Before manipulation, file = %s, dir = %s\n", debugstr_w(fodInfos->filename), debugstr_w(fodInfos->initdir));
 
   if(fodInfos->filename)
   {
diff --git a/dlls/comdlg32/filedlg31.c b/dlls/comdlg32/filedlg31.c
index d74b1be..b3d1c51 100644
--- a/dlls/comdlg32/filedlg31.c
+++ b/dlls/comdlg32/filedlg31.c
@@ -441,7 +441,7 @@ static LRESULT FD31_FileListSelect( const FD31_DATA *lfs )
     if (lRet == LB_ERR)
         return TRUE;
 
-    /* set the edit control to the choosen file */
+    /* set the edit control to the chosen file */
     if ((pstr = HeapAlloc(GetProcessHeap(), 0, BUFFILEALLOC)))
     {
         SendDlgItemMessageW(hWnd, lst1, LB_GETTEXT, lRet,
diff --git a/dlls/comdlg32/filedlgbrowser.h b/dlls/comdlg32/filedlgbrowser.h
index e45863a..7d55677 100644
--- a/dlls/comdlg32/filedlgbrowser.h
+++ b/dlls/comdlg32/filedlgbrowser.h
@@ -95,7 +95,7 @@ typedef struct
 } FileOpenDlgInfos;
 
 /***********************************************************************
- * Control ID's
+ * Control IDs
  */
 #define IDS_ABOUTBOX                    101
 #define IDS_DOCUMENTFOLDERS             102
diff --git a/dlls/comdlg32/finddlg.c b/dlls/comdlg32/finddlg.c
index e3a2c1a..bc4a31c 100644
--- a/dlls/comdlg32/finddlg.c
+++ b/dlls/comdlg32/finddlg.c
@@ -183,7 +183,7 @@ static INT_PTR CALLBACK COMDLG32_FindReplaceDlgProc(HWND hDlgWnd, UINT iMsg, WPA
                 pdata = (COMDLG32_FR_Data *)lParam;
 		if(!SetPropA(hDlgWnd, (LPSTR)COMDLG32_Atom, (HANDLE)pdata))
                 {
-			ERR("Could not Set prop; invent a gracefull exit?...\n");
+			ERR("Could not Set prop; invent a graceful exit?...\n");
 			DestroyWindow(hDlgWnd);
                         return FALSE;
                 }
diff --git a/dlls/comdlg32/printdlg.c b/dlls/comdlg32/printdlg.c
index 4d8b0c8..43967a9 100644
--- a/dlls/comdlg32/printdlg.c
+++ b/dlls/comdlg32/printdlg.c
@@ -2586,7 +2586,7 @@ static inline WORD get_devname_offset(const DEVNAMES *dn, devnames_name which)
     case devnames_device_name: return dn->wDeviceOffset;
     case devnames_output_name: return dn->wOutputOffset;
     }
-    ERR("Souldn't be here\n");
+    ERR("Shouldn't be here\n");
     return 0;
 }
 
diff --git a/dlls/commdlg.dll16/filedlg.c b/dlls/commdlg.dll16/filedlg.c
index 3586fed..3de8b90 100644
--- a/dlls/commdlg.dll16/filedlg.c
+++ b/dlls/commdlg.dll16/filedlg.c
@@ -63,7 +63,7 @@ BOOL16 CALLBACK FileSaveDlgProc16(HWND16 hWnd16, UINT16 wMsg, WPARAM16 wParam, L
  *    FALSE on cancel, error, close or filename-does-not-fit-in-buffer.
  *
  * BUGS
- *    unknown, there are some FIXME's left.
+ *    unknown, there are some FIXMEs left.
  */
 BOOL16 WINAPI GetOpenFileName16( SEGPTR ofn ) /* [in/out] address of structure with data*/
 {
@@ -116,7 +116,7 @@ BOOL16 WINAPI GetOpenFileName16( SEGPTR ofn ) /* [in/out] address of structure w
  *    FALSE on cancel, error, close or filename-does-not-fit-in-buffer.
  *
  * BUGS
- *    unknown. There are some FIXME's left.
+ *    unknown. There are some FIXMEs left.
  */
 BOOL16 WINAPI GetSaveFileName16( SEGPTR ofn ) /* [in/out] address of structure with data*/
 {
diff --git a/dlls/commdlg.dll16/finddlg.c b/dlls/commdlg.dll16/finddlg.c
index abd30d5..9def375 100644
--- a/dlls/commdlg.dll16/finddlg.c
+++ b/dlls/commdlg.dll16/finddlg.c
@@ -174,7 +174,7 @@ static LRESULT REPLACEDLG_WMInitDialog(HWND hWnd, LPARAM lParam,
     SetWindowLongPtrW(hWnd, DWLP_USER, lParam);
     *lpFlags &= ~(FR_FINDNEXT | FR_REPLACE | FR_REPLACEALL | FR_DIALOGTERM);
     /*
-     * FIXME : If the initial FindWhat string is empty, we should disable the FinNext /
+     * FIXME : If the initial FindWhat string is empty, we should disable the FindNext /
      * Replace / ReplaceAll buttons.  Only after typing some text, the buttons should be
      * enabled.
      */
diff --git a/dlls/credui/credui_main.c b/dlls/credui/credui_main.c
index a6bbde6..dd55ac0 100644
--- a/dlls/credui/credui_main.c
+++ b/dlls/credui/credui_main.c
@@ -260,7 +260,7 @@ static void CredDialogShowIncorrectPasswordBalloon(HWND hwndDlg, struct cred_dia
     SendMessageW(params->hwndBalloonTip, TTM_SETTITLEW, TTI_ERROR, (LPARAM)wszTitle);
 
     GetWindowRect(GetDlgItem(hwndDlg, IDC_PASSWORD), &rcPassword);
-    /* centred vertically and in the right side of the password edit control */
+    /* centered vertically and in the right side of the password edit control */
     x = rcPassword.right - 12;
     y = (rcPassword.top + rcPassword.bottom) / 2;
     SendMessageW(params->hwndBalloonTip, TTM_TRACKPOSITION, 0, MAKELONG(x, y));
diff --git a/dlls/crypt32/oid.c b/dlls/crypt32/oid.c
index ea7b539..9f998d9 100644
--- a/dlls/crypt32/oid.c
+++ b/dlls/crypt32/oid.c
@@ -591,7 +591,7 @@ BOOL WINAPI CryptGetDefaultOIDFunctionAddress(HCRYPTOIDFUNCSET hFuncSet,
  *             CryptRegisterOIDFunction (CRYPT32.@)
  *
  * Register the DLL and the functions it uses to cover the combination
- * of encoding type, functionname and OID.
+ * of encoding type, function name and OID.
  *
  * PARAMS
  *  dwEncodingType       [I] Encoding type to be used.
diff --git a/dlls/crypt32/serialize.c b/dlls/crypt32/serialize.c
index ab4c48a..5b6b794 100644
--- a/dlls/crypt32/serialize.c
+++ b/dlls/crypt32/serialize.c
@@ -167,7 +167,7 @@ BOOL WINAPI CertSerializeCTLStoreElement(PCCTL_CONTEXT pCtlContext,
 
 /* Looks for the property with ID propID in the buffer buf.  Returns a pointer
  * to its header if a valid header is found, NULL if not.  Valid means the
- * length of thte property won't overrun buf, and the unknown field is 1.
+ * length of the property won't overrun buf, and the unknown field is 1.
  */
 static const WINE_CERT_PROP_HEADER *CRYPT_findPropID(const BYTE *buf,
  DWORD size, DWORD propID)
diff --git a/dlls/cryptnet/cryptnet_main.c b/dlls/cryptnet/cryptnet_main.c
index 97d0ad8..ec9dddd 100644
--- a/dlls/cryptnet/cryptnet_main.c
+++ b/dlls/cryptnet/cryptnet_main.c
@@ -571,7 +571,7 @@ static BOOL CRYPT_GetObjectFromCache(LPCWSTR pszURL, PCRYPT_BLOB_ARRAY pObject,
     return ret;
 }
 
-/* Parses the URL, and sets components's lpszHostName and lpszUrlPath members
+/* Parses the URL, and sets components' lpszHostName and lpszUrlPath members
  * to NULL-terminated copies of those portions of the URL (to be freed with
  * CryptMemFree.)
  */
diff --git a/dlls/d3d10/effect.c b/dlls/d3d10/effect.c
index 542489c..ca10ba5 100644
--- a/dlls/d3d10/effect.c
+++ b/dlls/d3d10/effect.c
@@ -539,7 +539,7 @@ static HRESULT parse_fx10_type(struct d3d10_effect_type *t, const char *ptr, con
 
         /*
          * Not sure if this calculation is 100% correct, but a test
-         * show's that these values work.
+         * shows that these values work.
          */
         t->elementtype->size_unpacked = t->size_packed / t->element_count;
         TRACE("\tUnpacked size: %#x.\n", t->elementtype->size_unpacked);
diff --git a/dlls/d3d8/device.c b/dlls/d3d8/device.c
index e93976e..51c4ad7 100644
--- a/dlls/d3d8/device.c
+++ b/dlls/d3d8/device.c
@@ -3146,7 +3146,7 @@ HRESULT device_init(IDirect3DDevice8Impl *device, IDirect3D8Impl *parent, struct
     device->decls = HeapAlloc(GetProcessHeap(), 0, device->declArraySize * sizeof(*device->decls));
     if (!device->decls)
     {
-        ERR("Failed to allocate FVF vertex delcaration map memory.\n");
+        ERR("Failed to allocate FVF vertex declaration map memory.\n");
         hr = E_OUTOFMEMORY;
         goto err;
     }
diff --git a/dlls/d3d8/vertexdeclaration.c b/dlls/d3d8/vertexdeclaration.c
index 78a59d1..b972a21 100644
--- a/dlls/d3d8/vertexdeclaration.c
+++ b/dlls/d3d8/vertexdeclaration.c
@@ -193,7 +193,7 @@ size_t parse_token(const DWORD* pToken)
 
         default:
             TRACE(" 0x%08x UNKNOWN\n", token);
-            /* argg error */
+            /* arg error */
     }
 
     return tokenlen;
diff --git a/dlls/d3dcompiler_43/asmparser.c b/dlls/d3dcompiler_43/asmparser.c
index 789bdb5..ee4ba18 100644
--- a/dlls/d3dcompiler_43/asmparser.c
+++ b/dlls/d3dcompiler_43/asmparser.c
@@ -528,8 +528,7 @@ static void asmparser_instr(struct asm_parser *This, DWORD opcode,
     }
     TRACE_(parsed_shader)("\n");
 
- /* Check for instructions with different syntaxes in different shader versio
-ns */
+ /* Check for instructions with different syntaxes in different shader versions */
     switch(opcode) {
         case BWRITERSIO_SINCOS:
             /* The syntax changes between vs 2 and the other shader versions */
diff --git a/dlls/d3dxof/parsing.c b/dlls/d3dxof/parsing.c
index 4acaaba..1167456 100644
--- a/dlls/d3dxof/parsing.c
+++ b/dlls/d3dxof/parsing.c
@@ -1385,7 +1385,7 @@ _exit:
 
   if (buf->pxo->nb_childs > MAX_CHILDS)
   {
-    FIXME("Too many childs %d\n", buf->pxo->nb_childs);
+    FIXME("Too many children %d\n", buf->pxo->nb_childs);
     return FALSE;
   }
 
diff --git a/dlls/dbghelp/dbghelp_private.h b/dlls/dbghelp/dbghelp_private.h
index 43aca49..0e2aae7 100644
--- a/dlls/dbghelp/dbghelp_private.h
+++ b/dlls/dbghelp/dbghelp_private.h
@@ -485,7 +485,7 @@ struct cpu
     /* dwarf dedicated information */
     unsigned    (*map_dwarf_register)(unsigned regno);
 
-    /* context related maniputation */
+    /* context related manipulation */
     void*       (*fetch_context_reg)(CONTEXT* context, unsigned regno, unsigned* size);
     const char* (*fetch_regname)(unsigned regno);
 };
diff --git a/dlls/dbghelp/dwarf.c b/dlls/dbghelp/dwarf.c
index 2b3d54b..20bd080 100644
--- a/dlls/dbghelp/dwarf.c
+++ b/dlls/dbghelp/dwarf.c
@@ -1664,7 +1664,7 @@ static void dwarf2_parse_variable(dwarf2_subprogram_t* subpgm,
     }
     else
     {
-        /* variable has been optimiezd away... report anyway */
+        /* variable has been optimized away... report anyway */
         loc.kind = loc_error;
         loc.reg = loc_err_no_location;
         if (subpgm->func)
diff --git a/dlls/dbghelp/elf_module.c b/dlls/dbghelp/elf_module.c
index 19db48c..969e8c0 100644
--- a/dlls/dbghelp/elf_module.c
+++ b/dlls/dbghelp/elf_module.c
@@ -763,7 +763,7 @@ static int elf_new_wine_thunks(struct module* module, const struct hash_table* h
                  * we are adding new symbols, but as we're parsing a symbol table
                  * (hopefully without duplicate symbols) we delay rebuilding the sorted
                  * module table until we're done with the symbol table
-                 * Otherwise, as we intertwine symbols's add and lookup, performance
+                 * Otherwise, as we intertwine symbols' add and lookup, performance
                  * is rather bad
                  */
                 module->sortlist_valid = TRUE;
@@ -1285,7 +1285,7 @@ static BOOL elf_load_file_from_dll_path(HANDLE hProcess,
 /******************************************************************
  *		elf_search_auxv
  *
- * locate some a value from the debuggee auxillary vector
+ * locate some a value from the debuggee auxiliary vector
  */
 static BOOL elf_search_auxv(const struct process* pcs, unsigned type, unsigned long* val)
 {
@@ -1307,7 +1307,7 @@ static BOOL elf_search_auxv(const struct process* pcs, unsigned type, unsigned l
         return FALSE;
     }
     /* walk through envp[] */
-    /* envp[] strings are located after the auxillary vector, so protect the walk */
+    /* envp[] strings are located after the auxiliary vector, so protect the walk */
     str_max = (void*)(DWORD_PTR)~0L;
     while (ReadProcessMemory(pcs->handle, addr, &str, sizeof(str), NULL) &&
            (addr = (void*)((DWORD_PTR)addr + sizeof(str))) != NULL && str != NULL)
diff --git a/dlls/dbghelp/msc.c b/dlls/dbghelp/msc.c
index 451018b..9f9a53e 100644
--- a/dlls/dbghelp/msc.c
+++ b/dlls/dbghelp/msc.c
@@ -1398,7 +1398,7 @@ static void codeview_snarf_linetab(const struct msc_debug_info* msc_dbg, const B
             {
                 /* now locate function (if any) */
                 addr = func_addr0 + ltb->offsets[k] - start[j].start;
-                /* unfortunetaly, we can have several functions in the same block, if there's no
+                /* unfortunately, we can have several functions in the same block, if there's no
                  * gap between them... find the new function if needed
                  */
                 if (!func || addr >= func->address + func->size)
diff --git a/dlls/dbghelp/pe_module.c b/dlls/dbghelp/pe_module.c
index 6ab423a..ba7f1a2 100644
--- a/dlls/dbghelp/pe_module.c
+++ b/dlls/dbghelp/pe_module.c
@@ -88,7 +88,7 @@ const char* pe_map_section(struct image_section_map* ism)
             return IMAGE_NO_MAP;
         }
         /* FIXME: that's rather drastic, but that will do for now
-         * that's ok if the full file map exists, but we could be less agressive otherwise and
+         * that's ok if the full file map exists, but we could be less aggressive otherwise and
          * only map the relevant section
          */
         if ((mapping = pe_map_full(ism->fmap, &nth)))
diff --git a/dlls/ddeml.dll16/ddeml.c b/dlls/ddeml.dll16/ddeml.c
index c7cbd51..90362ca 100644
--- a/dlls/ddeml.dll16/ddeml.c
+++ b/dlls/ddeml.dll16/ddeml.c
@@ -155,7 +155,7 @@ static HDDEDATA	CALLBACK WDML_InvokeCallback16(DWORD pfn16, UINT uType, UINT uFm
  * a 32bit callback. This thunk also stores (in the code!) the 16bit
  * address of the 16bit callback, and passes it back to
  * WDML_InvokeCallback16.
- * The code below is mainly to create the thunks themselved
+ * The code below is mainly to create the thunks themselves
  */
 #include "pshpack1.h"
 static struct ddeml_thunk
diff --git a/dlls/ddraw/vertexbuffer.c b/dlls/ddraw/vertexbuffer.c
index 3983612..21a3b6f 100644
--- a/dlls/ddraw/vertexbuffer.c
+++ b/dlls/ddraw/vertexbuffer.c
@@ -47,7 +47,7 @@ static inline IDirect3DVertexBufferImpl *impl_from_IDirect3DVertexBuffer7(IDirec
  * For a link to QueryInterface rules, see IDirectDraw7::QueryInterface
  *
  * Params
- *  riid: Queryied Interface id
+ *  riid: Queried Interface id
  *  obj: Address to return the interface pointer
  *
  * Returns:
diff --git a/dlls/dinput/device.c b/dlls/dinput/device.c
index 58d4e14..147d648 100644
--- a/dlls/dinput/device.c
+++ b/dlls/dinput/device.c
@@ -431,7 +431,7 @@ static HRESULT create_DataFormat(LPCDIDATAFORMAT asked_format, DataFormat *forma
 		  * instance id.
 		  */
 		 ((asked_format->rgodf[j].dwType & DIDFT_INSTANCEMASK) == DIDFT_ANYINSTANCE) ||
-		 (DIDFT_GETINSTANCE(asked_format->rgodf[j].dwType) == 0x00FF) || /* This is mentionned in no DX docs, but it works fine - tested on WinXP */
+		 (DIDFT_GETINSTANCE(asked_format->rgodf[j].dwType) == 0x00FF) || /* This is mentioned in no DX docs, but it works fine - tested on WinXP */
 		 (DIDFT_GETINSTANCE(asked_format->rgodf[j].dwType) == DIDFT_GETINSTANCE(format->wine_df->rgodf[i].dwType)))
 		&&
 		( /* Then if the asked type matches the one Wine provides */
diff --git a/dlls/dinput/joystick_linuxinput.c b/dlls/dinput/joystick_linuxinput.c
index afdee1e..a88391c 100644
--- a/dlls/dinput/joystick_linuxinput.c
+++ b/dlls/dinput/joystick_linuxinput.c
@@ -427,7 +427,7 @@ static JoystickImpl *alloc_device(REFGUID rguid, IDirectInputImpl *dinput, unsig
     newDevice->ff_state    = FF_STATUS_STOPPED;
 #endif
     /* There is no way in linux to query force feedback autocenter status.
-       Instead, track it with ff_autocenter, and assume it's initialy
+       Instead, track it with ff_autocenter, and assume it's initially
        enabled. */
     newDevice->ff_autocenter = 1;
     newDevice->ff_gain = 0xFFFF;
@@ -716,8 +716,8 @@ static HRESULT WINAPI JoystickWImpl_Unacquire(LPDIRECTINPUTDEVICE8W iface)
       /* Enable autocenter. */
       event.type = EV_FF;
       event.code = FF_AUTOCENTER;
-      /* TODO: Read autocenter strengh before disabling it, and use it here
-       * instead of 0xFFFF (maximum strengh).
+      /* TODO: Read autocenter strength before disabling it, and use it here
+       * instead of 0xFFFF (maximum strength).
        */
       event.value = 0xFFFF;
       if (write(This->joyfd, &event, sizeof(event)) == -1)
diff --git a/dlls/dinput/joystick_osx.c b/dlls/dinput/joystick_osx.c
index 756a682..cbd005c 100644
--- a/dlls/dinput/joystick_osx.c
+++ b/dlls/dinput/joystick_osx.c
@@ -398,7 +398,7 @@ static void get_osx_device_elements(JoystickImpl *device, int axis_map[8])
                     int usagePage = IOHIDElementGetUsagePage( tIOHIDElementRef );
                     if (usagePage != kHIDPage_Button)
                     {
-                        /* avoid strange elements found on the 360 controler */
+                        /* avoid strange elements found on the 360 controller */
                         continue;
                     }
 
diff --git a/dlls/dinput/mouse.c b/dlls/dinput/mouse.c
index fb724d5..8da35f4 100644
--- a/dlls/dinput/mouse.c
+++ b/dlls/dinput/mouse.c
@@ -749,7 +749,7 @@ static HRESULT WINAPI SysMouseAImpl_GetDeviceInfo(
     TRACE("(this=%p,%p)\n", This, pdidi);
 
     if (pdidi->dwSize != sizeof(DIDEVICEINSTANCEA)) {
-        WARN(" dinput3 not supporte yet...\n");
+        WARN(" dinput3 not supported yet...\n");
 	return DI_OK;
     }
 
@@ -764,7 +764,7 @@ static HRESULT WINAPI SysMouseWImpl_GetDeviceInfo(LPDIRECTINPUTDEVICE8W iface, L
     TRACE("(this=%p,%p)\n", This, pdidi);
 
     if (pdidi->dwSize != sizeof(DIDEVICEINSTANCEW)) {
-        WARN(" dinput3 not supporte yet...\n");
+        WARN(" dinput3 not supported yet...\n");
 	return DI_OK;
     }
 
diff --git a/dlls/dispex/usrmarshal.c b/dlls/dispex/usrmarshal.c
index 2fcba52..a4f2b2b 100644
--- a/dlls/dispex/usrmarshal.c
+++ b/dlls/dispex/usrmarshal.c
@@ -1,5 +1,5 @@
 /*
- *    Misc marshaling routinues
+ *    Misc marshaling routines
  *
  * Copyright 2010 Huw Davies
  *
diff --git a/dlls/dmband/band.c b/dlls/dmband/band.c
index c2e56f6..19e3b86 100644
--- a/dlls/dmband/band.c
+++ b/dlls/dmband/band.c
@@ -282,7 +282,7 @@ static HRESULT WINAPI IDirectMusicBandImpl_IDirectMusicObject_ParseDescriptor (L
 												break;
 											}
 											default: {
-												TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+												TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 												liMove.QuadPart = Chunk.dwSize;
 												IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 												break;						
@@ -302,7 +302,7 @@ static HRESULT WINAPI IDirectMusicBandImpl_IDirectMusicObject_ParseDescriptor (L
 							break;
 						}	
 						default: {
-							TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+							TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 							liMove.QuadPart = Chunk.dwSize;
 							IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 							break;						
@@ -439,7 +439,7 @@ static HRESULT IDirectMusicBandImpl_IPersistStream_ParseInstrument (LPPERSISTSTR
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -508,7 +508,7 @@ static HRESULT IDirectMusicBandImpl_IPersistStream_ParseInstrumentsList (LPPERSI
 	break;
       }
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = ListSize[1];
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
@@ -517,7 +517,7 @@ static HRESULT IDirectMusicBandImpl_IPersistStream_ParseInstrumentsList (LPPERSI
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -582,7 +582,7 @@ static HRESULT IDirectMusicBandImpl_IPersistStream_ParseBandForm (LPPERSISTSTREA
 	    if (hr == S_FALSE) {
 	      switch (Chunk.fccID) {
 	      default: {
-		TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+		TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 		liMove.QuadPart = Chunk.dwSize;
 		IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 		break;						
@@ -609,7 +609,7 @@ static HRESULT IDirectMusicBandImpl_IPersistStream_ParseBandForm (LPPERSISTSTREA
 	break;
       }
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = Chunk.dwSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
diff --git a/dlls/dmband/bandtrack.c b/dlls/dmband/bandtrack.c
index e08a9e8..7d5ed0c 100644
--- a/dlls/dmband/bandtrack.c
+++ b/dlls/dmband/bandtrack.c
@@ -401,7 +401,7 @@ static HRESULT IDirectMusicBandTrack_IPersistStream_ParseBandsList (LPPERSISTSTR
 	    break;
 	  }
 	  default: {
-	    TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	    TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	    liMove.QuadPart = StreamSize;
 	    IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	    break;						
@@ -410,7 +410,7 @@ static HRESULT IDirectMusicBandTrack_IPersistStream_ParseBandsList (LPPERSISTSTR
 	  break;
 	}
 	default: {
-	  TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	  TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	  liMove.QuadPart = Chunk.dwSize;
 	  IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	  break;						
@@ -421,7 +421,7 @@ static HRESULT IDirectMusicBandTrack_IPersistStream_ParseBandsList (LPPERSISTSTR
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -484,7 +484,7 @@ static HRESULT IDirectMusicBandTrack_IPersistStream_ParseBandTrackForm (LPPERSIS
 	    if (hr == S_FALSE) {
 	      switch (Chunk.fccID) {
 	      default: {
-		TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+		TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 		liMove.QuadPart = Chunk.dwSize;
 		IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 		break;				
@@ -511,7 +511,7 @@ static HRESULT IDirectMusicBandTrack_IPersistStream_ParseBandTrackForm (LPPERSIS
 	break;
       }
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = Chunk.dwSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
diff --git a/dlls/dmband/dmutils.c b/dlls/dmband/dmutils.c
index 3cffdd5..7915af5 100644
--- a/dlls/dmband/dmutils.c
+++ b/dlls/dmband/dmutils.c
@@ -290,7 +290,7 @@ HRESULT IDirectMusicUtils_IPersistStream_ParseReference (LPPERSISTSTREAM iface,
 	break;
       } 
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = Chunk.dwSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
diff --git a/dlls/dmcompos/chordmap.c b/dlls/dmcompos/chordmap.c
index 7529df6..4e2480f 100644
--- a/dlls/dmcompos/chordmap.c
+++ b/dlls/dmcompos/chordmap.c
@@ -272,7 +272,7 @@ static HRESULT WINAPI IDirectMusicChordMapImpl_IDirectMusicObject_ParseDescripto
 												break;
 											}
 											default: {
-												TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+												TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 												liMove.QuadPart = Chunk.dwSize;
 												IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 												break;						
@@ -292,7 +292,7 @@ static HRESULT WINAPI IDirectMusicChordMapImpl_IDirectMusicObject_ParseDescripto
 							break;
 						}	
 						default: {
-							TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+							TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 							liMove.QuadPart = Chunk.dwSize;
 							IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 							break;						
@@ -453,7 +453,7 @@ static HRESULT WINAPI IDirectMusicChordMapImpl_IPersistStream_Load (LPPERSISTSTR
 													break;
 												}
 												default: {
-													TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+													TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 													liMove.QuadPart = chunkSize;
 													IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 													break;						
@@ -473,7 +473,7 @@ static HRESULT WINAPI IDirectMusicChordMapImpl_IPersistStream_Load (LPPERSISTSTR
 								break;
 							}	
 							default: {
-								TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+								TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 								liMove.QuadPart = chunkSize;
 								IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 								break;						
diff --git a/dlls/dmime/audiopath.c b/dlls/dmime/audiopath.c
index 08c961d..eede097 100644
--- a/dlls/dmime/audiopath.c
+++ b/dlls/dmime/audiopath.c
@@ -383,7 +383,7 @@ static HRESULT WINAPI IDirectMusicAudioPathImpl_IDirectMusicObject_ParseDescript
 												break;
 											}
 											default: {
-												TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+												TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 												liMove.QuadPart = Chunk.dwSize;
 												IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 												break;						
@@ -403,7 +403,7 @@ static HRESULT WINAPI IDirectMusicAudioPathImpl_IDirectMusicObject_ParseDescript
 							break;
 						}	
 						default: {
-							TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+							TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 							liMove.QuadPart = Chunk.dwSize;
 							IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 							break;						
@@ -563,7 +563,7 @@ static HRESULT WINAPI IDirectMusicAudioPathImpl_IPersistStream_Load (LPPERSISTST
 													break;
 												}
 												default: {
-													TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+													TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 													liMove.QuadPart = chunkSize;
 													IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 													break;						
@@ -583,7 +583,7 @@ static HRESULT WINAPI IDirectMusicAudioPathImpl_IPersistStream_Load (LPPERSISTST
 								break;
 							}	
 							default: {
-								TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+								TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 								liMove.QuadPart = chunkSize;
 								IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 								break;						
diff --git a/dlls/dmime/dmutils.c b/dlls/dmime/dmutils.c
index 614677c..73d5e43 100644
--- a/dlls/dmime/dmutils.c
+++ b/dlls/dmime/dmutils.c
@@ -186,7 +186,7 @@ HRESULT IDirectMusicUtils_IPersistStream_ParseReference (LPPERSISTSTREAM iface,
 	break;
       } 
       default: {
-	TRACE(": unknown chunk (irrevelant & skipping)\n");
+	TRACE(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = Chunk.dwSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
diff --git a/dlls/dmime/graph.c b/dlls/dmime/graph.c
index 6f9f705..f9e29a3 100644
--- a/dlls/dmime/graph.c
+++ b/dlls/dmime/graph.c
@@ -348,7 +348,7 @@ static HRESULT WINAPI IDirectMusicGraphImpl_IDirectMusicObject_ParseDescriptor (
 												break;
 											}
 											default: {
-												TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+												TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 												liMove.QuadPart = Chunk.dwSize;
 												IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 												break;						
@@ -368,7 +368,7 @@ static HRESULT WINAPI IDirectMusicGraphImpl_IDirectMusicObject_ParseDescriptor (
 							break;
 						}	
 						default: {
-							TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+							TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 							liMove.QuadPart = Chunk.dwSize;
 							IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 							break;						
@@ -527,7 +527,7 @@ static HRESULT WINAPI IDirectMusicGraphImpl_IPersistStream_Load (LPPERSISTSTREAM
 													break;
 												}
 												default: {
-													TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+													TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 													liMove.QuadPart = chunkSize;
 													IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 													break;						
@@ -547,7 +547,7 @@ static HRESULT WINAPI IDirectMusicGraphImpl_IPersistStream_Load (LPPERSISTSTREAM
 								break;
 							}	
 							default: {
-								TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+								TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 								liMove.QuadPart = chunkSize;
 								IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 								break;						
diff --git a/dlls/dmime/segment.c b/dlls/dmime/segment.c
index ca127d7..df3c2a6 100644
--- a/dlls/dmime/segment.c
+++ b/dlls/dmime/segment.c
@@ -674,7 +674,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_IDirectMusicObject_ParseDescripto
 												break;
 											}
 											default: {
-												TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+												TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 												liMove.QuadPart = Chunk.dwSize;
 												IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 												break;						
@@ -692,7 +692,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_IDirectMusicObject_ParseDescripto
                                                                     TRACE_(dmfile)(": %s chunk (size = %d)", debugstr_fourcc (Chunk.fccID), Chunk.dwSize);
 								    switch (Chunk.fccID) {
 								    default: {
-								      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+								      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 								      liMove.QuadPart = Chunk.dwSize;
 								      IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 								      break;						
@@ -712,7 +712,7 @@ static HRESULT WINAPI IDirectMusicSegment8Impl_IDirectMusicObject_ParseDescripto
 							break;
 						}	
 						default: {
-							TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+							TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 							liMove.QuadPart = Chunk.dwSize;
 							IStream_Seek (pStream, liMove, STREAM_SEEK_CUR, NULL);
 							break;						
@@ -971,7 +971,7 @@ static HRESULT IDirectMusicSegment8Impl_IPersistStream_ParseTrackForm (LPPERSIST
 	break;
       }
 
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -1015,7 +1015,7 @@ static HRESULT IDirectMusicSegment8Impl_IPersistStream_ParseTrackList (LPPERSIST
 	break;
       }
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = StreamSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;
@@ -1024,7 +1024,7 @@ static HRESULT IDirectMusicSegment8Impl_IPersistStream_ParseTrackList (LPPERSIST
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -1124,7 +1124,7 @@ static HRESULT IDirectMusicSegment8Impl_IPersistStream_ParseSegmentForm (LPPERSI
 	    if (hr == S_FALSE) {
 	      switch (Chunk.fccID) {
 	      default: {
-		TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+		TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 		liMove.QuadPart = Chunk.dwSize;
 		IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 		break;						
@@ -1152,7 +1152,7 @@ static HRESULT IDirectMusicSegment8Impl_IPersistStream_ParseSegmentForm (LPPERSI
 	break;
       }
       default: {
-	TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+	TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
 	liMove.QuadPart = Chunk.dwSize;
 	IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
 	break;						
diff --git a/dlls/dmime/segtriggertrack.c b/dlls/dmime/segtriggertrack.c
index 16fd3c3..221feeb 100644
--- a/dlls/dmime/segtriggertrack.c
+++ b/dlls/dmime/segtriggertrack.c
@@ -326,7 +326,7 @@ static HRESULT IDirectMusicSegTriggerTrack_IPersistStream_ParseSegment (LPPERSIS
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -380,7 +380,7 @@ static HRESULT IDirectMusicSegTriggerTrack_IPersistStream_ParseSegmentsList (LPP
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
@@ -440,7 +440,7 @@ static HRESULT IDirectMusicSegTriggerTrack_IPersistStream_ParseSegTrackList (LPP
       break;
     }
     default: {
-      TRACE_(dmfile)(": unknown chunk (irrevelant & skipping)\n");
+      TRACE_(dmfile)(": unknown chunk (irrelevant & skipping)\n");
       liMove.QuadPart = Chunk.dwSize;
       IStream_Seek (pStm, liMove, STREAM_SEEK_CUR, NULL);
       break;						
diff --git a/dlls/ddraw/ddraw.c b/dlls/ddraw/ddraw.c
index 70e8895..daea1ca 100644
--- a/dlls/ddraw/ddraw.c
+++ b/dlls/ddraw/ddraw.c
@@ -215,7 +215,7 @@ static HRESULT WINAPI ddraw7_QueryInterface(IDirectDraw7 *iface, REFIID refiid,
         }
         else if(This->ImplType != SURFACE_OPENGL && DefaultSurfaceType == SURFACE_UNKNOWN)
         {
-            ERR("(%p) The App is requesting a D3D device, but a non-OpenGL surface type was choosen. Prepare for trouble!\n", This);
+            ERR("(%p) The App is requesting a D3D device, but a non-OpenGL surface type was chosen. Prepare for trouble!\n", This);
             ERR(" (%p) You may want to contact wine-devel for help\n", This);
             /* Should I assert(0) here??? */
         }
@@ -2734,7 +2734,7 @@ static HRESULT ddraw_create_surface(IDirectDrawImpl *This, DDSURFACEDESC2 *pDDSD
         DDRAW_dump_surface_desc(pDDSD);
     }
 
     /* Select the surface type, if it wasn't choosen yet */
     if(ImplType == SURFACE_UNKNOWN)
     {
         /* Use GL Surfaces if a D3DDEVICE Surface is requested */
@@ -2734,7 +2734,7 @@ static HRESULT ddraw_create_surface(IDirectDrawImpl *This, DDSURFACEDESC2 *pDDSD
     }
 
-    /* Select the surface type, if it wasn't choosen yet */
+    /* Select the surface type, if it wasn't chosen yet */
     if(ImplType == SURFACE_UNKNOWN)
     {
-- 
1.7.6




More information about the wine-patches mailing list